@@ -33,7 +33,9 @@ class SyncUploader::Private
 {
 public:
     Private()
-    :mCurrentMedia(0),success(false)
+    :mCurrentMedia(0),
+      loop(0),
+      success(false)
     {}
     BilboMedia *mCurrentMedia;
     QEventLoop *loop;
@@ -45,6 +47,7 @@ SyncUploader::SyncUploader( QObject *parent )
     :QObject(parent),d(new Private)
 {
 }
+
 SyncUploader::~SyncUploader()
 {
     delete d;
@@ -57,8 +60,7 @@ QString SyncUploader::errorMessage() const
 
 bool SyncUploader::uploadMedia( Backend *backend, BilboMedia *media )
 {
-    kDebug();
-    if(!backend || !media){
+    if (!backend || !media){
         kError()<<"Media or Backend is NULL";
         return false;
     }
@@ -69,7 +71,7 @@ bool SyncUploader::uploadMedia( Backend *backend, BilboMedia *media )
                 this, SLOT(slotMediaError(QString,BilboMedia*)) );
 
     backend->uploadMedia( media );
-    if( d->loop->exec()==0 )
+    if ( d->loop->exec()==0 )
         return true;
     else
         return false;
@@ -77,7 +79,7 @@ bool SyncUploader::uploadMedia( Backend *backend, BilboMedia *media )
 
 void SyncUploader::slotMediaFileUploaded( BilboMedia *media )
 {
-    if(media && media == d->mCurrentMedia){
+    if (media && media == d->mCurrentMedia){
         kDebug();
         d->success = true;
         d->loop->exit();
@@ -86,8 +88,7 @@ void SyncUploader::slotMediaFileUploaded( BilboMedia *media )
 
 void SyncUploader::slotMediaError( const QString &errorMessage, BilboMedia* media )
 {
-    kDebug();
-    if(media && media == d->mCurrentMedia){
+    if (media && media == d->mCurrentMedia){
         d->success = false;
         d->error = errorMessage;
         d->loop->exit(1);
