@@ -1386,7 +1386,7 @@ void KOPrefsDialogPlugins::usrWriteConfig()
 {
   QStringList selectedPlugins;
 
-  for ( int i = 0; i < mTreeWidget->topLevelItemCount(); i++) {
+  for ( int i = 0; i < mTreeWidget->topLevelItemCount(); ++i) {
     QTreeWidgetItem *serviceTypeGroup = mTreeWidget->topLevelItem( i );
     for ( int j = 0; j < serviceTypeGroup->childCount(); j++) {
       PluginItem *item = static_cast<PluginItem *>( serviceTypeGroup->child( j ) );
