@@ -26,14 +26,11 @@
 #define KORG_VIEWS_KOJOURNALVIEW_H
 
 #include "korganizer/baseview.h"
-
 #include <KCalCore/Incidence> // for KCalCore::DateList typedef
 
-class JournalDateView;
-
-class KVBox;
-
-class QScrollArea;
+namespace EventViews {
+  class JournalView;
+}
 
 /**
  * This class provides a journal view.
@@ -57,42 +54,30 @@ class KOJournalView : public KOrg::BaseView
       return KCalCore::DateList();
     }
 
-    void appendJournal( const Akonadi::Item &journal, const QDate &dt );
+    void setCalendar( const Akonadi::ETMCalendar::Ptr & );
 
-    /** documentation in baseview.h */
+    /** reimp */
     void getHighlightMode( bool &highlightEvents,
                            bool &highlightTodos,
                            bool &highlightJournals );
 
-    bool eventFilter ( QObject *, QEvent * );
-    virtual KOrg::CalPrinterBase::PrintType printType() const;
+    /** reimp */
+    KOrg::CalPrinterBase::PrintType printType() const;
 
-  public slots:
-    // Don't update the view when midnight passed, otherwise we'll have data loss (bug 79145)
-    virtual void dayPassed( const QDate & ) {}
+  public Q_SLOTS:
     void updateView();
     void flushView();
 
     void showDates( const QDate &start, const QDate &end, const QDate &preferredMonth = QDate() );
     void showIncidences( const Akonadi::Item::List &incidences, const QDate &date );
 
-    void changeIncidenceDisplay( const Akonadi::Item &incidence, int );
-    void setIncidenceChanger( CalendarSupport::IncidenceChanger *changer );
-    void newJournal();
-  signals:
-    void flushEntries();
-    void setIncidenceChangerSignal( CalendarSupport::IncidenceChanger * );
-    void journalEdited( const Akonadi::Item &journal );
-    void journalDeleted( const Akonadi::Item &journal );
-
-  protected:
-    void clearEntries();
+    void changeIncidenceDisplay( const Akonadi::Item &incidence,
+                                 Akonadi::IncidenceChanger::ChangeType );
+    void setIncidenceChanger( Akonadi::IncidenceChanger *changer );
+    void printJournal( const KCalCore::Journal::Ptr &journal );
 
   private:
-    QScrollArea *mSA;
-    KVBox *mVBox;
-    QMap<QDate, JournalDateView*> mEntries;
-//    DateList mSelectedDates;  // List of dates to be displayed
+    EventViews::JournalView *mJournalView;
 };
 
 #endif
