@@ -34,7 +34,7 @@ class FilterActionRewriteHeader: public FilterActionWithStringList
 {
   Q_OBJECT
   public:
-    FilterActionRewriteHeader( QObject *parent = 0 );
+    explicit FilterActionRewriteHeader( QObject *parent = 0 );
     virtual ReturnCode process( ItemContext &context ) const;
     virtual SearchRule::RequiredPart requiredPart() const;
     virtual QWidget* createParamWidget( QWidget *parent ) const;
