@@ -1007,7 +1007,7 @@ void Pane::writeConfig()
   KConfigGroup conf( MessageList::Core::Settings::self()->config(),"MessageListPane");
 
   // Delete list before
-  const QStringList list = conf.groupList().filter( QRegExp( QLatin1String("MessageListTab\\d+") ) );
+  const QStringList list = MessageList::Core::Settings::self()->config()->groupList().filter( QRegExp( QLatin1String("MessageListTab\\d+") ) );
   foreach ( const QString &group, list ) {
     conf.deleteGroup( group );
   }
