@@ -174,6 +174,11 @@ bool Widget::selectFirstMessageItem( MessageList::Core::MessageTypeFilter messag
   return view()->selectFirstMessageItem( messageTypeFilter, centerItem );
 }
 
+bool Widget::selectLastMessageItem( Core::MessageTypeFilter messageTypeFilter, bool centerItem )
+{
+  return view()->selectLastMessageItem( messageTypeFilter, centerItem );
+}
+
 void Widget::selectAll()
 {
   view()->setAllGroupsExpanded( true );
@@ -204,11 +209,11 @@ void Widget::focusQuickSearch()
 void Widget::fillMessageTagCombo( KComboBox * combo )
 {
   KConfigGroup conf( MessageList::Core::Settings::self()->config(),"MessageListView");
-  QString tagSelected= conf.readEntry(QLatin1String("TagSelected"));
+  const QString tagSelected= conf.readEntry(QLatin1String("TagSelected"));
   if(tagSelected.isEmpty()) {
     return;
   }
-  const QStringList tagSelectedLst = tagSelected.split(QLatin1String(","));
+  const QStringList tagSelectedLst = tagSelected.split(QLatin1Char(','));
   foreach( const Nepomuk2::Tag &nepomukTag, Nepomuk2::Tag::allTags() ) {
     const QString id = nepomukTag.uri().toString();
     if(tagSelectedLst.contains(id)) {
