@@ -43,10 +43,6 @@ QString GrantleeHeaderTestStyle::format( KMime::Message *message ) const
 {
     if ( !message )
         return QString();
-    const HeaderStrategy *strategy = headerStrategy();
-    if ( !strategy )
-        strategy = HeaderStrategy::grantlee();
-
     return mGrantleeFormatter->toHtml(mExtraDisplay, mAbsolutePath, mMainFilename, this, message, isPrinting());
 }
 
