@@ -19,9 +19,9 @@
 
 #include "configwidget.h"
 
-#include "messagecomposer/messagecomposersettings.h"
+#include "messagecomposer/settings/messagecomposersettings.h"
 #include "messagelistsettings.h"
-#include "messageviewer/globalsettings.h"
+#include "messageviewer/settings/globalsettings.h"
 #include "settings.h"
 #include "stylesheetloader.h"
 #include "templateparser/globalsettings_base.h"
